@@ -505,6 +505,7 @@ class Xcmd:
     #  the string representation of an Xcmd object.
     mutable_args = {
         "queue": "-q",
+        "bank": "-B",
         "ntasks": "-n",
         "nodes": "-N",
         "cores_per_task": "-c",
@@ -757,6 +758,13 @@ class MiniCmd:
             description=description,
             formatter_class=flux.util.help_formatter(),
         )
+        parser.add_argument(
+            "-B",
+            "--bank",
+            type=str,
+            metavar="BANK",
+            help="Submit a job to a specific named bank",
+        )
         parser.add_argument(
             "-q",
             "--queue",
@@ -793,6 +801,7 @@ class MiniCmd:
             metavar="OPT",
         )
         parser.add_argument(
+            "-S",
             "--setattr",
             action="append",
             help="Set job attribute ATTR. An optional value is supported "
@@ -1042,6 +1051,9 @@ class MiniCmd:
         if args.queue is not None:
             jobspec.setattr("system.queue", args.queue)
 
+        if args.bank is not None:
+            jobspec.setattr("system.bank", args.bank)
+
         if args.setattr is not None:
             for keyval in args.setattr:
                 key, val = parse_jobspec_keyval("--setattr", keyval)
@@ -1221,6 +1233,11 @@ class SubmitBaseCmd(MiniCmd):
         if not args.command:
             raise ValueError("job command and arguments are missing")
 
+        #  Remove first -- from command in case user used it to separate
+        #  Flux cli options from command and options
+        if args.command[0] == "--":
+            args.command.pop(0)
+
         #  Ensure integer args are converted to int() here.
         #  This is done because we do not use type=int in argparse in order
         #   to allow these options to be mutable for bulksubmit:
@@ -1425,7 +1442,6 @@ class SubmitBulkCmd(SubmitBaseCmd):
             args.progress = None
 
     def watcher_start(self, args):
-
         if not self.watcher:
             #  Need to open self.flux_handle if it isn't already in order
             #  to start the watcher
